@@ -107,11 +107,23 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     """
     if prop:
         if prop not in abr2prop.keys():
+            ##JOAO
+            print("prop not in abr2prop.keys")
+            ##JOAO
             raise propertyError(prop)
         else:
-            # prp = properties[prop][0]
+            ##JOAO
+            propr = properties[prop][0]
+            print("propr: ",propr)
+            ##JOAO
             prp = abr2key[prop]
+            ##JOAO
+            print("prp: ",prp)
+            ##JOAO
     else:
+        ##JOAO
+        print("deu else no prop do modem do badjora")
+        ##JOAO
         prp = ''
     params = dict(
         cmp = comp,
@@ -124,7 +136,13 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
     if len(resDict['errors']) > 0:
+        ##JOAO
+        print("deu petara do modem do badjora")
+        ##JOAO
         e = " *** ".join(resDict['errors'])
+        ##JOAO
+        print("deu erro:", e)
+        ##JOAO
         raise queryError(e)
     return result(resDict)
 
